==> krita-5.1.5.tar.xz: krita-5.1.5/libs/pigment/resources/KoColorSet_p.h <==
/*
 *  SPDX-License-Identifier: GPL-3.0-or-later
 */

#ifndef KOCOLORSET_P_H
#define KOCOLORSET_P_H

#include <QHash>
#include <QXmlStreamReader>
#include <QDomElement>
#include <QPointer>

#include <KisSwatch.h>
#include <KisSwatchGroup.h>

#include "KoColorSet.h"

struct RiffHeader {
    quint32 riff;
    quint32 size;
    quint32 signature;
    quint32 data;
    quint32 datasize;
    quint16 version;
    quint16 colorcount;
};

class KoColorSet::Private
{
private:
    typedef KisSwatchGroup::SwatchInfo SwatchInfoType;

public:
    Private(KoColorSet *a_colorSet);

public:
    KisSwatchGroup &global() {
        Q_ASSERT(groups.contains(GLOBAL_GROUP_NAME));
        return groups[GLOBAL_GROUP_NAME];
    }
public:
    bool init();

    bool saveGpl(QIODevice *dev) const;
    bool loadGpl();

    bool loadAct();
    bool loadRiff();
    bool loadPsp();
    bool loadAco();
    bool loadXml();
    bool loadSbz();
    bool loadAse();
    bool loadAcb();

    bool saveKpl(QIODevice *dev) const;
    bool loadKpl();

public:
    KoColorSet *colorSet {0};
    KoColorSet::PaletteType paletteType {UNKNOWN};
    QByteArray data;
    QString comment;
    QStringList groupNames; //names of the groups, this is used to determine the order they are in.
    QHash<QString, KisSwatchGroup> groups; //grouped colors.

private:
    KoColorSet::PaletteType detectFormat(const QString &fileName, const QByteArray &ba);
    void scribusParseColor(KoColorSet *set, QXmlStreamReader *xml);
    bool loadScribusXmlPalette(KoColorSet *set, QXmlStreamReader *xml);
    quint8 readByte(QIODevice *io);
    quint16 readShort(QIODevice *io);
    qint32 readInt(QIODevice *io);
    float readFloat(QIODevice *io);
    QString readUnicodeString(QIODevice *io, bool sizeIsInt = false);

    void saveKplGroup(QDomDocument &doc, QDomElement &groupEle,
                      const KisSwatchGroup *group, QSet<const KoColorSpace *> &colorSetSet) const;
    void loadKplGroup(const QDomDocument &doc, const QDomElement &parentElement, KisSwatchGroup *group, QString version);
};

#endif // KOCOLORSET_P_H

==> krita_5.2.9+dfsg.orig.tar.xz: krita-5.2.9/libs/pigment/resources/KoColorSet_p.h <==
/*
 *  SPDX-License-Identifier: GPL-3.0-or-later
 */

#ifndef KOCOLORSET_P_H
#define KOCOLORSET_P_H

#include <QHash>
#include <QXmlStreamReader>
#include <QDomElement>
#include <QPointer>
#include <kundo2stack.h>

#include <KisSwatch.h>
#include <KisSwatchGroup.h>

#include "KoColorSet.h"

struct RiffHeader {
    quint32 riff;
    quint32 size;
    quint32 signature;
    quint32 data;
    quint32 datasize;
    quint16 version;
    quint16 colorcount;
};

class KoColorSet::Private
{

public:
    Private(KoColorSet *a_colorSet);

public:
    KisSwatchGroupSP global() {
        Q_ASSERT(swatchGroups.size() > 0 && swatchGroups.first()->name() == GLOBAL_GROUP_NAME);
        return swatchGroups.first();
    }
public:
    bool init();

    bool saveGpl(QIODevice *dev) const;
    bool loadGpl();

    bool loadAct();
    bool loadRiff();
    bool loadPsp();
    bool loadAco();
    bool loadXml();
    bool loadSbz();
    bool loadAse();
    bool loadAcb();

    bool saveKpl(QIODevice *dev) const;
    bool loadKpl();

public:

    KoColorSet *colorSet {0};
    KoColorSet::PaletteType paletteType {UNKNOWN};
    QByteArray data;
    QString comment;
    QList<KisSwatchGroupSP> swatchGroups;
    KUndo2Stack undoStack;
    bool isLocked {false};
    int columns;

private:

    friend struct AddSwatchCommand;
    friend struct RemoveSwatchCommand;
    friend struct ChangeGroupNameCommand;
    friend struct AddGroupCommand;
    friend struct RemoveGroupCommand;
    friend struct ClearCommand;
    friend struct SetColumnCountCommand;
    friend struct SetCommentCommand;
    friend struct SetPaletteTypeCommand;
    friend struct MoveGroupCommand;

    KoColorSet::PaletteType detectFormat(const QString &fileName, const QByteArray &ba);
    void scribusParseColor(KoColorSet *set, QXmlStreamReader *xml);
    bool loadScribusXmlPalette(KoColorSet *set, QXmlStreamReader *xml);
    quint8 readByte(QIODevice *io);
    quint16 readShort(QIODevice *io);
    qint32 readInt(QIODevice *io);
    float readFloat(QIODevice *io);
    QString readUnicodeString(QIODevice *io, bool sizeIsInt = false);

    void saveKplGroup(QDomDocument &doc, QDomElement &groupEle,
                      const KisSwatchGroupSP group, QSet<const KoColorSpace *> &colorSetSet) const;
    void loadKplGroup(const QDomDocument &doc, const QDomElement &parentElement, KisSwatchGroupSP group, QString version);
};

#endif // KOCOLORSET_P_H
